@@ -25,8 +25,6 @@
 #include "demos.h"
 #include "fontify.h"
 
-#include "demo_conf.h"
-
 static GtkWidget *info_view;
 static GtkWidget *source_view;
 
@@ -198,20 +196,16 @@ activate_about (GSimpleAction *action,
                           gtk_get_micro_version ());
   g_string_append_printf (s, "\nA link can appear here: <http://www.gtk.org>");
 
-  version = g_strdup_printf ("%s%s%s\nRunning against GTK %d.%d.%d",
+  version = g_strdup_printf ("%s\nRunning against GTK %d.%d.%d",
                              PACKAGE_VERSION,
-                             g_strcmp0 (PROFILE, "devel") == 0 ? "-" : "",
-                             g_strcmp0 (PROFILE, "devel") == 0 ? VCS_TAG : "",
                              gtk_get_major_version (),
                              gtk_get_minor_version (),
                              gtk_get_micro_version ());
 
   gtk_show_about_dialog (GTK_WINDOW (gtk_application_get_active_window (app)),
-                         "program-name", g_strcmp0 (PROFILE, "devel") == 0
-                                         ? "GTK Demo (Development)"
-                                         : "GTK Demo",
+                         "program-name", "GTK Demo",
                          "version", version,
-                         "copyright", "© 1997—2021 The GTK Team",
+                         "copyright", "© 1997—2020 The GTK Team",
                          "license-type", GTK_LICENSE_LGPL_2_1,
                          "website", "http://www.gtk.org",
                          "comments", "Program to demonstrate GTK widgets",
@@ -751,6 +745,7 @@ demo_filter_by_name (gpointer item,
                      gpointer user_data)
 {
   GtkTreeListRow *row = item;
+  GtkFilterListModel *model = user_data;
   GListModel *children;
   GtkDemo *demo;
   guint i, n;
@@ -761,7 +756,7 @@ demo_filter_by_name (gpointer item,
     return TRUE;
 
   g_assert (GTK_IS_TREE_LIST_ROW (row));
-  g_assert (GTK_IS_FILTER_LIST_MODEL (user_data));
+  g_assert (GTK_IS_FILTER_LIST_MODEL (model));
 
   /* Show a row if itself of any parent matches */
   for (parent = row; parent; parent = gtk_tree_list_row_get_parent (parent))
@@ -906,9 +901,6 @@ activate (GApplication *app)
   window = (GtkWidget *)gtk_builder_get_object (builder, "window");
   gtk_application_add_window (GTK_APPLICATION (app), GTK_WINDOW (window));
 
-  if (g_strcmp0 (PROFILE, "devel") == 0)
-    gtk_widget_add_css_class (window, "devel");
-
   action = g_simple_action_new ("run", NULL);
   g_signal_connect (action, "activate", G_CALLBACK (activate_run), window);
   g_action_map_add_action (G_ACTION_MAP (window), G_ACTION (action));
@@ -1051,10 +1043,10 @@ out:
 static void
 print_version (void)
 {
-  g_print ("gtk4-demo %s%s%s\n",
-           PACKAGE_VERSION,
-           g_strcmp0 (PROFILE, "devel") == 0 ? "-" : "",
-           g_strcmp0 (PROFILE, "devel") == 0 ? VCS_TAG : "");
+  g_print ("gtk4-demo %d.%d.%d\n",
+           gtk_get_major_version (),
+           gtk_get_minor_version (),
+           gtk_get_micro_version ());
 }
 
 static int
