@@ -28,8 +28,6 @@
 #include "gtkversion.h"
 #include "gdkprofilerprivate.h"
 
-#include "gtkprivate.h"
-
 #include <gio/gio.h>
 #include <string.h>
 
@@ -206,14 +204,14 @@ gtk_buildable_parse_context_parse (GtkBuildableParseContext *context,
 
 /**
  * gtk_buildable_parse_context_push:
- * @context: a `GtkBuildableParseContext`
- * @parser: a `GtkBuildableParser`
- * @user_data: user data to pass to `GtkBuildableParser` functions
+ * @context: a #GtkBuildableParseContext
+ * @parser: a #GtkBuildableParser
+ * @user_data: user data to pass to #GtkBuildableParser functions
  *
  * Temporarily redirects markup data to a sub-parser.
  *
  * This function may only be called from the start_element handler of
- * a `GtkBuildableParser`. It must be matched with a corresponding call to
+ * a #GtkBuildableParser. It must be matched with a corresponding call to
  * gtk_buildable_parse_context_pop() in the matching end_element handler
  * (except in the case that the parser aborts due to an error).
  *
@@ -262,7 +260,7 @@ gtk_buildable_parse_context_push (GtkBuildableParseContext *context,
 
 /**
  * gtk_buildable_parse_context_pop:
- * @context: a `GtkBuildableParseContext`
+ * @context: a #GtkBuildableParseContext
  *
  * Completes the process of a temporary sub-parser redirection.
  *
@@ -300,7 +298,7 @@ gtk_buildable_parse_context_pop (GtkBuildableParseContext *context)
 
 /**
  * gtk_buildable_parse_context_get_element:
- * @context: a `GtkBuildablParseContext`
+ * @context: a #GtkBuildablParseContext
  *
  * Retrieves the name of the currently open element.
  *
@@ -308,7 +306,7 @@ gtk_buildable_parse_context_pop (GtkBuildableParseContext *context)
  * give the element_name as passed to those functions. For the parent
  * elements, see gtk_buildable_parse_context_get_element_stack().
  *
- * Returns: (nullable): the name of the currently open element
+ * Returns: (nullable): the name of the currently open element, or %NULL
  */
 const char *
 gtk_buildable_parse_context_get_element (GtkBuildableParseContext *context)
@@ -320,11 +318,11 @@ gtk_buildable_parse_context_get_element (GtkBuildableParseContext *context)
 
 /**
  * gtk_buildable_parse_context_get_element_stack:
- * @context: a `GtkBuildableParseContext`
+ * @context: a #GtkBuildableParseContext
  *
  * Retrieves the element stack from the internal state of the parser.
  *
- * The returned `GPtrArray` is an array of strings where the last item is
+ * The returned #GPtrArray is an array of strings where the last item is
  * the currently open tag (as would be returned by
  * gtk_buildable_parse_context_get_element()) and the previous item is its
  * immediate parent.
@@ -344,9 +342,9 @@ gtk_buildable_parse_context_get_element_stack (GtkBuildableParseContext *context
 
 /**
  * gtk_buildable_parse_context_get_position:
- * @context: a `GtkBuildableParseContext`
- * @line_number: (out) (optional): return location for a line number
- * @char_number: (out) (optional): return location for a char-on-line number
+ * @context: a #GtkBuildableParseContext
+ * @line_number: (out) (optional): return location for a line number, or %NULL
+ * @char_number: (out) (optional): return location for a char-on-line number, or %NULL
  *
  * Retrieves the current line number and the number of the character on
  * that line. Intended for use in error messages; there are no strict
@@ -1612,7 +1610,7 @@ create_subparser (GObject       *object,
   subparser->child = child;
   subparser->tagname = g_strdup (element_name);
   subparser->start = element_name;
-  subparser->parser = g_memdup2 (parser, sizeof (GtkBuildableParser));
+  subparser->parser = g_memdup (parser, sizeof (GtkBuildableParser));
   subparser->data = user_data;
 
   return subparser;
@@ -2006,7 +2004,6 @@ end_element (GtkBuildableParseContext  *context,
           PropertyInfo *prop_info = (PropertyInfo *) parent_info;
 
           prop_info->value = expression_info_construct (data->builder, expression_info, error);
-          free_expression_info (expression_info);
         }
       else if (parent_info->tag_type == TAG_EXPRESSION)
         {
