@@ -19,9 +19,6 @@
 
 #include "gtkcssnodedeclarationprivate.h"
 
-/* XXX: For g_memdup2() */
-#include "gtkprivate.h"
-
 #include <string.h>
 
 struct _GtkCssNodeDeclaration {
@@ -54,7 +51,7 @@ gtk_css_node_declaration_make_writable (GtkCssNodeDeclaration **decl)
 
   (*decl)->refcount--;
 
-  *decl = g_memdup2 (*decl, sizeof_this_node (*decl));
+  *decl = g_memdup (*decl, sizeof_this_node (*decl));
   (*decl)->refcount = 1;
 }
 
