@@ -317,38 +317,14 @@ parse_letter_spacing (GtkCssStyleProperty *property,
   return _gtk_css_number_value_parse (parser, GTK_CSS_PARSE_LENGTH);
 }
 
-static gboolean
-value_is_done_parsing (GtkCssParser *parser)
-{
-  return gtk_css_parser_has_token (parser, GTK_CSS_TOKEN_EOF) ||
-         gtk_css_parser_has_token (parser, GTK_CSS_TOKEN_COMMA) ||
-         gtk_css_parser_has_token (parser, GTK_CSS_TOKEN_SEMICOLON) ||
-         gtk_css_parser_has_token (parser, GTK_CSS_TOKEN_CLOSE_CURLY);
-}
-
 static GtkCssValue *
 parse_text_decoration_line (GtkCssStyleProperty *property,
                             GtkCssParser        *parser)
 {
-  GtkCssValue *value = NULL;
-  GtkTextDecorationLine line;
+  GtkCssValue *value = _gtk_css_text_decoration_line_value_try_parse (parser);
 
-  line = 0;
-  do {
-    GtkTextDecorationLine parsed;
-
-    parsed = _gtk_css_text_decoration_line_try_parse_one (parser, line);
-    if (parsed == 0 || parsed == line)
-      {
-        gtk_css_parser_error_syntax (parser, "Not a valid value");
-        return NULL;
-      }
-    line = parsed;
-  } while (!value_is_done_parsing (parser));
-
-  value = _gtk_css_text_decoration_line_value_new (line);
   if (value == NULL)
-    gtk_css_parser_error_syntax (parser, "Invalid combination of values");
+    gtk_css_parser_error_syntax (parser, "unknown text decoration line value");
 
   return value;
 }
@@ -377,6 +353,15 @@ parse_font_kerning (GtkCssStyleProperty *property,
   return value;
 }
 
+static gboolean
+value_is_done_parsing (GtkCssParser *parser)
+{
+  return gtk_css_parser_has_token (parser, GTK_CSS_TOKEN_EOF) ||
+         gtk_css_parser_has_token (parser, GTK_CSS_TOKEN_COMMA) ||
+         gtk_css_parser_has_token (parser, GTK_CSS_TOKEN_SEMICOLON) ||
+         gtk_css_parser_has_token (parser, GTK_CSS_TOKEN_CLOSE_CURLY);
+}
+
 static GtkCssValue *
 parse_font_variant_ligatures (GtkCssStyleProperty *property,
                               GtkCssParser        *parser)
@@ -512,14 +497,14 @@ static GtkCssValue *
 box_shadow_value_parse (GtkCssStyleProperty *property,
                         GtkCssParser        *parser)
 {
-  return gtk_css_shadow_value_parse (parser, TRUE);
+  return _gtk_css_shadow_value_parse (parser, TRUE);
 }
 
 static GtkCssValue *
 shadow_value_parse (GtkCssStyleProperty *property,
                     GtkCssParser        *parser)
 {
-  return gtk_css_shadow_value_parse (parser, FALSE);
+  return _gtk_css_shadow_value_parse (parser, FALSE);
 }
 
 static GtkCssValue *
@@ -805,13 +790,6 @@ background_position_parse (GtkCssStyleProperty *property,
   return _gtk_css_array_value_parse (parser, _gtk_css_position_value_parse);
 }
 
-static GtkCssValue *
-transform_origin_parse (GtkCssStyleProperty *property,
-                        GtkCssParser        *parser)
-{
-  return _gtk_css_position_value_parse (parser);
-}
-
 /*** REGISTRATION ***/
 
 G_STATIC_ASSERT (GTK_CSS_PROPERTY_COLOR == 0);
@@ -1270,13 +1248,6 @@ _gtk_css_style_property_init_properties (void)
                                           GTK_CSS_AFFECTS_TRANSFORM,
                                           transform_value_parse,
                                           _gtk_css_transform_value_new_none ());
-  gtk_css_style_property_register        ("transform-origin",
-                                          GTK_CSS_PROPERTY_TRANSFORM_ORIGIN,
-                                          GTK_STYLE_PROPERTY_ANIMATED,
-                                          GTK_CSS_AFFECTS_TRANSFORM,
-                                          transform_origin_parse,
-                                          _gtk_css_position_value_new (_gtk_css_number_value_new (50, GTK_CSS_PERCENT),
-                                                                       _gtk_css_number_value_new (50, GTK_CSS_PERCENT)));
   gtk_css_style_property_register        ("min-width",
                                           GTK_CSS_PROPERTY_MIN_WIDTH,
                                           GTK_STYLE_PROPERTY_ANIMATED,
