@@ -36,16 +36,20 @@
 
 
 /**
- * GtkDropTarget:
+ * SECTION:gtkdroptarget
+ * @Short_description: Event controller to receive DND drops
+ * @Title: GtkDropTarget
+ * @See_also: #GdkDrop, #GtkDropTargetAsync
  *
- * `GtkDropTarget` is an event controller to receive Drag-and-Drop operations.
+ * GtkDropTarget is an event controller implementing a simple way to
+ * receive Drag-and-Drop operations.
  *
- * The most basic way to use a `GtkDropTarget` to receive drops on a
- * widget is to create it via [ctor@Gtk.DropTarget.new], passing in the
- * `GType` of the data you want to receive and connect to the
- * [signal@Gtk.DropTarget::drop] signal to receive the data:
+ * The most basic way to use a #GtkDropTarget to receive drops on a
+ * widget is to create it via gtk_drop_target_new() passing in the
+ * #GType of the data you want to receive and connect to the
+ * #GtkDropTarget::drop signal to receive the data:
  *
- * ```c
+ * |[<!-- language="C" -->
  * static gboolean
  * on_drop (GtkDropTarget *target,
  *          const GValue  *value,
@@ -82,32 +86,28 @@
  *
  *   gtk_widget_add_controller (GTK_WIDGET (self), GTK_EVENT_CONTROLLER (target));
  * }
- * ```
+ * ]|
  *
- * `GtkDropTarget` supports more options, such as:
+ * #GtkDropTarget supports more options, such as:
  *
- *  * rejecting potential drops via the [signal@Gtk.DropTarget::accept] signal
- *    and the [method@Gtk.DropTarget.reject] function to let other drop
+ *  * rejecting potential drops via the #GtkDropTarget::accept signal
+ *    and the gtk_drop_target_reject() function to let other drop
  *    targets handle the drop
  *  * tracking an ongoing drag operation before the drop via the
- *    [signal@Gtk.DropTarget::enter], [signal@Gtk.DropTarget::motion] and
- *    [signal@Gtk.DropTarget::leave] signals
+ *    #GtkDropTarget::enter, #GtkDropTarget::motion and
+ *    #GtkDropTarget::leave signals
  *  * configuring how to receive data by setting the
- *    [property@Gtk.DropTarget:preload] property and listening for its
- *    availability via the [property@Gtk.DropTarget:value] property
+ *    #GtkDropTarget:preload property and listening for its availability
+ *    via the #GtkDropTarget:value property
  *
- * However, `GtkDropTarget` is ultimately modeled in a synchronous way
- * and only supports data transferred via `GType`. If you want full control
- * over an ongoing drop, the [class@Gtk.DropTargetAsync] object gives you
- * this ability.
+ * However, #GtkDropTarget is ultimately modeled in a synchronous way
+ * and only supports data transferred via #GType.  
+ * If you want full control over an ongoing drop, the #GtkDropTargetAsync
+ * object gives you this ability.
  *
  * While a pointer is dragged over the drop target's widget and the drop
  * has not been rejected, that widget will receive the
  * %GTK_STATE_FLAG_DROP_ACTIVE state, which can be used to style the widget.
- *
- * If you are not interested in receiving the drop, but just want to update
- * UI state during a Drag-and-Drop operation (e.g. switching tabs), you can
- * use [class@Gtk.DropControllerMotion].
  */
 
 struct _GtkDropTarget
@@ -148,7 +148,6 @@ struct _GtkDropTargetClass
 enum {
   PROP_0,
   PROP_ACTIONS,
-  PROP_CURRENT_DROP,
   PROP_DROP,
   PROP_FORMATS,
   PROP_PRELOAD,
@@ -187,7 +186,6 @@ gtk_drop_target_end_drop (GtkDropTarget *self)
 
   g_clear_object (&self->drop);
   g_object_notify_by_pspec (G_OBJECT (self), properties[PROP_DROP]);
-  g_object_notify_by_pspec (G_OBJECT (self), properties[PROP_CURRENT_DROP]);
 
   if (G_IS_VALUE (&self->value))
     {
@@ -322,7 +320,6 @@ gtk_drop_target_start_drop (GtkDropTarget *self,
 
   self->drop = g_object_ref (drop);
   g_object_notify_by_pspec (G_OBJECT (self), properties[PROP_DROP]);
-  g_object_notify_by_pspec (G_OBJECT (self), properties[PROP_CURRENT_DROP]);
 
   if (self->preload)
     gtk_drop_target_load (self);
@@ -568,7 +565,6 @@ gtk_drop_target_get_property (GObject    *object,
       break;
 
     case PROP_DROP:
-    case PROP_CURRENT_DROP:
       g_value_set_object (value, self->drop);
       break;
 
@@ -612,10 +608,10 @@ gtk_drop_target_class_init (GtkDropTargetClass *class)
   class->drop = gtk_drop_target_drop;
 
   /**
-   * GtkDropTarget:actions: (attributes org.gtk.Property.get=gtk_drop_target_get_actions org.gtk.Property.set=gtk_drop_target_set_actions)
+   * GtkDropTarget:actions:
    *
-   * The `GdkDragActions` that this drop target supports.
-   */
+   * The #GdkDragActions that this drop target supports
+   */ 
   properties[PROP_ACTIONS] =
        g_param_spec_flags ("actions",
                            P_("Actions"),
@@ -624,37 +620,21 @@ gtk_drop_target_class_init (GtkDropTargetClass *class)
                            G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * GtkDropTarget:drop: (attributes org.gtk.Property.get=gtk_drop_target_get_drop) (skip)
+   * GtkDropTarget:drop:
    *
-   * The `GdkDrop` that is currently being performed.
-   *
-   * Deprecated: 4.4: Use [property@Gtk.DropTarget:current-drop] instead
+   * The #GdkDrop that is currently being performed
    */
   properties[PROP_DROP] =
        g_param_spec_object ("drop",
                             P_("Drop"),
                             P_("Current drop"),
                             GDK_TYPE_DROP,
-                            GTK_PARAM_READABLE | G_PARAM_DEPRECATED);
-
-  /**
-   * GtkDropTarget:current-drop: (attributes org.gtk.Property.get=gtk_drop_target_get_current_drop)
-   *
-   * The `GdkDrop` that is currently being performed.
-   *
-   * Since: 4.4
-   */
-  properties[PROP_CURRENT_DROP] =
-       g_param_spec_object ("current-drop",
-                            P_("Current drop"),
-                            P_("Current drop"),
-                            GDK_TYPE_DROP,
                             GTK_PARAM_READABLE);
 
   /**
-   * GtkDropTarget:formats: (attributes org.gtk.Property.get=gtk_drop_target_get_formats)
+   * GtkDropTarget:formats:
    *
-   * The `GdkContentFormats` that determine the supported data formats.
+   * The #GdkContentFormats that determine the supported data formats
    */
   properties[PROP_FORMATS] =
        g_param_spec_boxed ("formats",
@@ -664,7 +644,7 @@ gtk_drop_target_class_init (GtkDropTargetClass *class)
                            GTK_PARAM_READABLE);
 
   /**
-   * GtkDropTarget:preload: (attributes org.gtk.Property.get=gtk_drop_target_get_preload org.gtk.Property.set=gtk_drop_target_set_preload)
+   * GtkDropTarget:preload:
    *
    * Whether the drop data should be preloaded when the pointer is only
    * hovering over the widget but has not been released.
@@ -673,16 +653,15 @@ gtk_drop_target_class_init (GtkDropTargetClass *class)
    * drop at the cost of loading more data.
    *
    * The default value for this property is %FALSE to avoid downloading
-   * huge amounts of data by accident.
-   *
+   * huge amounts of data by accident.  
    * For example, if somebody drags a full document of gigabytes of text
    * from a text editor across a widget with a preloading drop target,
    * this data will be downloaded, even if the data is ultimately dropped
    * elsewhere.
    *
    * For a lot of data formats, the amount of data is very small (like
-   * %GDK_TYPE_RGBA), so enabling this property does not hurt at all.
-   * And for local-only Drag-and-Drop operations, no data transfer is done,
+   * %GDK_TYPE_RGBA), so enabling this property does not hurt at all.  
+   * And for local-only drag'n'drop operations, no data transfer is done,
    * so enabling it there is free.
    */
   properties[PROP_PRELOAD] =
@@ -693,17 +672,14 @@ gtk_drop_target_class_init (GtkDropTargetClass *class)
                              G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | G_PARAM_EXPLICIT_NOTIFY);
 
   /**
-   * GtkDropTarget:value: (attributes org.gtk.Property.get=gtk_drop_target_get_value)
+   * GtkDropTarget:value:
    *
-   * The value for this drop operation.
+   * The value for this drop operation or %NULL if the data has not been
+   * loaded yet or no drop operation is going on.
    *
-   * This is %NULL if the data has not been loaded yet or no drop
-   * operation is going on.
-   *
-   * Data may be available before the [signal@Gtk.DropTarget::drop]
-   * signal gets emitted - for example when the [property@Gtk.DropTarget:preload]
-   * property is set. You can use the ::notify signal to be notified
-   * of available data.
+   * Data may be available before the #GtkDropTarget::drop signal gets emitted -
+   * for example when the #GtkDropTarget:preload property is set.
+   * You can use the #GObject::notify signal to be notified of available data.
    */
   properties[PROP_VALUE] =
        g_param_spec_boxed ("value",
@@ -716,25 +692,24 @@ gtk_drop_target_class_init (GtkDropTargetClass *class)
 
  /**
    * GtkDropTarget::accept:
-   * @self: the `GtkDropTarget`
-   * @drop: the `GdkDrop`
-   *
-   * Emitted on the drop site when a drop operation is about to begin.
+   * @self: the #GtkDropTarget
+   * @drop: the #GdkDrop
    *
+   * The ::accept signal is emitted on the drop site when a drop operation
+   * is about to begin.
    * If the drop is not accepted, %FALSE will be returned and the drop target
    * will ignore the drop. If %TRUE is returned, the drop is accepted for now
-   * but may be rejected later via a call to [method@Gtk.DropTarget.reject]
-   * or ultimately by returning %FALSE from a [signal@Gtk.DropTarget::drop]
-   * handler.
+   * but may be rejected later via a call to gtk_drop_target_reject() or
+   * ultimately by returning %FALSE from #GtkDropTarget::drop.
    *
    * The default handler for this signal decides whether to accept the drop
    * based on the formats provided by the @drop.
    *
    * If the decision whether the drop will be accepted or rejected depends
-   * on the data, this function should return %TRUE, the
-   * [property@Gtk.DropTarget:preload] property should be set and the value
-   * should be inspected via the ::notify:value signal, calling
-   * [method@Gtk.DropTarget.reject] if required.
+   * on the data, this function should return %TRUE, the #GtkDropTarget:preload
+   * property should be set and the value should be inspected via the
+   * #GObject::notify:value signal, calling gtk_drop_target_reject() if
+   * required.
    *
    * Returns: %TRUE if @drop is accepted
    */
@@ -750,16 +725,15 @@ gtk_drop_target_class_init (GtkDropTargetClass *class)
 
   /**
    * GtkDropTarget::enter:
-   * @self: the `GtkDropTarget`
+   * @self: the #GtkDropTarget
    * @x: the x coordinate of the current pointer position
    * @y: the y coordinate of the current pointer position
    *
-   * Emitted on the drop site when the pointer enters the widget.
+   * The ::enter signal is emitted on the drop site when the pointer
+   * enters the widget. It can be used to set up custom highlighting.
    *
-   * It can be used to set up custom highlighting.
-   *
-   * Returns: Preferred action for this drag operation or 0 if
-   *   dropping is not supported at the current @x,@y location.
+   * Returns: Preferred action for this drag operation or 0 if dropping is not
+   *     supported at the current @x,@y location.
    */
   signals[ENTER] =
       g_signal_new (I_("enter"),
@@ -773,14 +747,15 @@ gtk_drop_target_class_init (GtkDropTargetClass *class)
 
   /**
    * GtkDropTarget::motion:
-   * @self: the `GtkDropTarget`
+   * @self: the #GtkDropTarget
    * @x: the x coordinate of the current pointer position
    * @y: the y coordinate of the current pointer position
    *
-   * Emitted while the pointer is moving over the drop target.
+   * The ::motion signal is emitted while the pointer is moving
+   * over the drop target.
    *
-   * Returns: Preferred action for this drag operation or 0 if
-   *   dropping is not supported at the current @x,@y location.
+   * Returns: Preferred action for this drag operation or 0 if dropping is not
+   *     supported at the current @x,@y location.
    */
   signals[MOTION] =
       g_signal_new (I_("motion"),
@@ -794,12 +769,11 @@ gtk_drop_target_class_init (GtkDropTargetClass *class)
 
   /**
    * GtkDropTarget::leave:
-   * @self: the `GtkDropTarget`
+   * @self: the #GtkDropTarget
    *
-   * Emitted on the drop site when the pointer leaves the widget.
-   *
-   * Its main purpose it to undo things done in
-   * [signal@Gtk.DropTarget::enter].
+   * The ::leave signal is emitted on the drop site when the pointer
+   * leaves the widget. Its main purpose it to undo things done in
+   * #GtkDropTarget::enter.
    */
   signals[LEAVE] =
       g_signal_new (I_("leave"),
@@ -812,19 +786,18 @@ gtk_drop_target_class_init (GtkDropTargetClass *class)
 
   /**
    * GtkDropTarget::drop:
-   * @self: the `GtkDropTarget`
-   * @value: the `GValue` being dropped
+   * @self: the #GtkDropTarget
+   * @value: the #GValue being dropped
    * @x: the x coordinate of the current pointer position
    * @y: the y coordinate of the current pointer position
    *
-   * Emitted on the drop site when the user drops the data onto the widget.
-   *
-   * The signal handler must determine whether the pointer position is in
-   * a drop zone or not. If it is not in a drop zone, it returns %FALSE
-   * and no further processing is necessary.
+   * The ::drop signal is emitted on the drop site when the user drops
+   * the data onto the widget. The signal handler must determine whether
+   * the pointer position is in a drop zone or not. If it is not in a drop
+   * zone, it returns %FALSE and no further processing is necessary.
    *
    * Otherwise, the handler returns %TRUE. In this case, this handler will
-   * accept the drop. The handler is responsible for using the given @value
+   * accept the drop. The handler is responsible for rading the given @value
    * and performing the drop operation.
    *
    * Returns: whether the drop was accepted at the given pointer position
@@ -851,13 +824,13 @@ gtk_drop_target_init (GtkDropTarget *self)
  * @type: The supported type or %G_TYPE_INVALID
  * @actions: the supported actions
  *
- * Creates a new `GtkDropTarget` object.
+ * Creates a new #GtkDropTarget object.
  *
  * If the drop target should support more than 1 type, pass
  * %G_TYPE_INVALID for @type and then call
- * [method@Gtk.DropTarget.set_gtypes].
+ * gtk_drop_target_set_gtypes().
  *
- * Returns: the new `GtkDropTarget`
+ * Returns: the new #GtkDropTarget
  */
 GtkDropTarget *
 gtk_drop_target_new (GType         type,
@@ -876,8 +849,8 @@ gtk_drop_target_new (GType         type,
 }
 
 /**
- * gtk_drop_target_get_formats: (attributes org.gtk.Method.get_property=formats)
- * @self: a `GtkDropTarget`
+ * gtk_drop_target_get_formats:
+ * @self: a #GtkDropTarget
  *
  * Gets the data formats that this drop target accepts.
  *
@@ -895,13 +868,13 @@ gtk_drop_target_get_formats (GtkDropTarget *self)
 
 /**
  * gtk_drop_target_set_gtypes:
- * @self: a `GtkDropTarget`
- * @types: (nullable) (transfer none) (array length=n_types): all supported `GType`s
- *   that can be dropped on the target
+ * @self: a #GtkDropTarget
+ * @types: (nullable) (transfer none) (array length=n_types):
+ *     all supported #GTypes that can be dropped
  * @n_types: number of @types
  *
- * Sets the supported `GTypes` for this drop target.
- */
+ * Sets the supported #GTypes for this drop target.
+ **/
 void
 gtk_drop_target_set_gtypes (GtkDropTarget *self,
                             GType         *types,
@@ -926,18 +899,17 @@ gtk_drop_target_set_gtypes (GtkDropTarget *self,
 
 /**
  * gtk_drop_target_get_gtypes:
- * @self: a `GtkDropTarget`
- * @n_types: (out) (optional): the number of `GType`s contained in the
- *   return value
+ * @self: a #GtkDropTarget
+ * @n_types: (out) (optional): optional pointer to take the
+ *     number of #GTypes contained in the return value
  *
- * Gets the list of supported `GType`s that can be dropped on the target.
- *
- * If no types have been set, `NULL` will be returned.
+ * Gets the list of supported #GTypes for @self. If no type have been set,
+ * %NULL will be returned.
  *
  * Returns: (transfer none) (nullable) (array length=n_types):
- *   the `G_TYPE_INVALID`-terminated array of types included in
- *   formats
- */
+ *      %G_TYPE_INVALID-terminated array of types included in @formats or
+ *      %NULL if none.
+ **/
 const GType *
 gtk_drop_target_get_gtypes (GtkDropTarget *self,
                             gsize         *n_types)
@@ -948,8 +920,8 @@ gtk_drop_target_get_gtypes (GtkDropTarget *self,
 }
 
 /**
- * gtk_drop_target_set_actions: (attributes org.gtk.Method.set_property=actions)
- * @self: a `GtkDropTarget`
+ * gtk_drop_target_set_actions:
+ * @self: a #GtkDropTarget
  * @actions: the supported actions
  *
  * Sets the actions that this drop target supports.
@@ -969,8 +941,8 @@ gtk_drop_target_set_actions (GtkDropTarget *self,
 }
 
 /**
- * gtk_drop_target_get_actions: (attributes org.gtk.Method.get_property=actions)
- * @self: a `GtkDropTarget`
+ * gtk_drop_target_get_actions:
+ * @self: a #GtkDropTarget
  *
  * Gets the actions that this drop target supports.
  *
@@ -985,12 +957,12 @@ gtk_drop_target_get_actions (GtkDropTarget *self)
 }
 
 /**
- * gtk_drop_target_set_preload: (attributes org.gtk.Method.set_property=preload)
- * @self: a `GtkDropTarget`
+ * gtk_drop_target_set_preload:
+ * @self: a #GtkDropTarget
  * @preload: %TRUE to preload drop data
  *
- * Sets whether data should be preloaded on hover.
- */
+ * Sets the GtkDropTarget:preload property.
+ **/
 void
 gtk_drop_target_set_preload (GtkDropTarget *self,
                              gboolean       preload)
@@ -1006,10 +978,10 @@ gtk_drop_target_set_preload (GtkDropTarget *self,
 }
 
 /**
- * gtk_drop_target_get_preload: (attributes org.gtk.Method.get_property=preload)
- * @self: a `GtkDropTarget`
+ * gtk_drop_target_get_preload:
+ * @self: a #GtkDropTarget
  *
- * Gets whether data should be preloaded on hover.
+ * Gets the value of the GtkDropTarget:preload property.
  *
  * Returns: %TRUE if drop data should be preloaded
  */
@@ -1022,17 +994,15 @@ gtk_drop_target_get_preload (GtkDropTarget *self)
 }
 
 /**
- * gtk_drop_target_get_drop: (attributes org.gtk.Method.get_property=drop)
- * @self: a `GtkDropTarget`
+ * gtk_drop_target_get_drop:
+ * @self: a #GtkDropTarget
  *
  * Gets the currently handled drop operation.
  *
  * If no drop operation is going on, %NULL is returned.
  *
  * Returns: (nullable) (transfer none): The current drop
- *
- * Deprecated: 4.4: Use [method@Gtk.DropTarget.get_current_drop] instead
- */
+ **/
 GdkDrop *
 gtk_drop_target_get_drop (GtkDropTarget *self)
 {
@@ -1042,33 +1012,13 @@ gtk_drop_target_get_drop (GtkDropTarget *self)
 }
 
 /**
- * gtk_drop_target_get_current_drop: (attributes org.gtk.Method.get_property=current-drop)
- * @self: a `GtkDropTarget`
+ * gtk_drop_target_get_value:
+ * @self: a #GtkDropTarget
  *
- * Gets the currently handled drop operation.
- *
- * If no drop operation is going on, %NULL is returned.
- *
- * Returns: (nullable) (transfer none): The current drop
- *
- * Since: 4.4
- */
-GdkDrop *
-gtk_drop_target_get_current_drop (GtkDropTarget *self)
-{
-  g_return_val_if_fail (GTK_IS_DROP_TARGET (self), NULL);
-
-  return self->drop;
-}
-
-/**
- * gtk_drop_target_get_value: (attributes org.gtk.Method.get_property=value)
- * @self: a `GtkDropTarget`
- *
- * Gets the current drop data, as a `GValue`.
+ * Gets the value of the GtkDropTarget:value property.
  *
  * Returns: (nullable) (transfer none): The current drop data
- */
+ **/
 const GValue *
 gtk_drop_target_get_value (GtkDropTarget *self)
 {
@@ -1082,12 +1032,12 @@ gtk_drop_target_get_value (GtkDropTarget *self)
 
 /**
  * gtk_drop_target_reject:
- * @self: a `GtkDropTarget`
+ * @self: a #GtkDropTarget
  *
  * Rejects the ongoing drop operation.
  *
- * If no drop operation is ongoing, i.e when [property@Gtk.DropTarget:current-drop]
- * is %NULL, this function does nothing.
+ * If no drop operation is ongoing - when GdkDropTarget:drop
+ * returns %NULL - this function does nothing.
  *
  * This function should be used when delaying the decision
  * on whether to accept a drag or not until after reading
