@@ -21,7 +21,7 @@
 
 #include "config.h"
 
-#include "gtkpasswordentrybuffer.h"
+#include "gtkpasswordentrybufferprivate.h"
 
 #include "gtksecurememoryprivate.h"
 
@@ -30,16 +30,6 @@
 /* Initial size of buffer, in bytes */
 #define MIN_SIZE 16
 
-/**
- * GtkPasswordEntryBuffer:
- *
- * A `GtkEntryBuffer` that locks the underlying memory to prevent it
- * from being swapped to disk.
- *
- * `GtkPasswordEntry` uses a `GtkPasswordEntryBuffer`.
- *
- * Since 4.4.
- */
 struct _GtkPasswordEntryBuffer
 {
   GtkEntryBuffer parent_instance;
@@ -202,10 +192,10 @@ gtk_password_entry_buffer_init (GtkPasswordEntryBuffer *self)
 {
 }
 
-/**
+/*< private >
  * gtk_password_entry_buffer_new:
  *
- * Creates a new `GtkEntryBuffer` using secure memory allocations.
+ * Creates a new #GtkEntryBuffer using secure memory allocations.
  *
  * Returns: (transfer full): the newly created instance
  */
