@@ -36,40 +36,34 @@
 #include "gtkshortcutmanager.h"
 #include "gtkshortcutcontroller.h"
 #include "gtkbuildable.h"
-#include "gtkscrolledwindow.h"
-#include "gtkviewport.h"
 
 
 /**
- * GtkPopoverMenu:
+ * SECTION:gtkpopovermenu
+ * @Short_description: Popovers to use as menus
+ * @Title: GtkPopoverMenu
  *
- * `GtkPopoverMenu` is a subclass of `GtkPopover` that implements menu
- * behavior.
+ * GtkPopoverMenu is a subclass of #GtkPopover that treats its
+ * children like menus and allows switching between them. It
+ * can open submenus as traditional, nested submenus, or in a
+ * more touch-friendly sliding fashion.
  *
- * ![An example GtkPopoverMenu](menu.png)
- *
- * `GtkPopoverMenu` treats its children like menus and allows switching
- * between them. It can open submenus as traditional, nested submenus,
- * or in a more touch-friendly sliding fashion.
- *
- * `GtkPopoverMenu` is meant to be used primarily with menu models,
- * using [ctor@Gtk.PopoverMenu.new_from_model]. If you need to put
- * other widgets such as a `GtkSpinButton` or a `GtkSwitch` into a popover,
- * you can use [method@Gtk.PopoverMenu.add_child].
- *
- * For more dialog-like behavior, use a plain `GtkPopover`.
+ * GtkPopoverMenu is meant to be used primarily with menu models,
+ * using gtk_popover_menu_new_from_model(). If you need to put other
+ * widgets such as #GtkSpinButton or #GtkSwitch into a popover,
+ * use a plain #GtkPopover.
  *
  * ## Menu models
  *
- * The XML format understood by `GtkBuilder` for `GMenuModel` consists
+ * The XML format understood by #GtkBuilder for #GMenuModel consists
  * of a toplevel `<menu>` element, which contains one or more `<item>`
  * elements. Each `<item>` element contains `<attribute>` and `<link>`
  * elements with a mandatory name attribute. `<link>` elements have the
- * same content model as `<menu>`. Instead of `<link name="submenu">`
- * or `<link name="section">`, you can use `<submenu>` or `<section>`
+ * same content model as `<menu>`. Instead of `<link name="submenu>` or
+ * `<link name="section">`, you can use `<submenu>` or `<section>`
  * elements.
  *
- * ```xml
+ * |[<!-- language="xml" -->
  * <menu id='app-menu'>
  *   <section>
  *     <item>
@@ -86,63 +80,57 @@
  *     </item>
  *   </section>
  * </menu>
- * ```
+ * ]|
  *
- * Attribute values can be translated using gettext, like other `GtkBuilder`
+ * Attribute values can be translated using gettext, like other #GtkBuilder
  * content. `<attribute>` elements can be marked for translation with a
  * `translatable="yes"` attribute. It is also possible to specify message
  * context and translator comments, using the context and comments attributes.
- * To make use of this, the `GtkBuilder` must have been given the gettext
+ * To make use of this, the #GtkBuilder must have been given the gettext
  * domain to use.
  *
  * The following attributes are used when constructing menu items:
- *
  * - "label": a user-visible string to display
  * - "action": the prefixed name of the action to trigger
  * - "target": the parameter to use when activating the action
  * - "icon" and "verb-icon": names of icons that may be displayed
- * - "submenu-action": name of an action that may be used to track
- *      whether a submenu is open
+ * - "submenu-action": name of an action that may be used to determine
+ *      if a submenu can be opened
  * - "hidden-when": a string used to determine when the item will be hidden.
  *      Possible values include "action-disabled", "action-missing", "macos-menubar".
- *      This is mainly useful for exported menus, see [method@Gtk.Application.set_menubar].
- * - "custom": a string used to match against the ID of a custom child added with
- *      [method@Gtk.PopoverMenu.add_child], [method@Gtk.PopoverMenuBar.add_child],
- *      or in the ui file with `<child type="ID">`.
+ *      This is mainly useful for exported menus, see gtk_application_set_menubar().
+ * - "custom": a string used to match against the ID of a custom child added
+ *      with gtk_popover_menu_add_child(), gtk_popover_menu_bar_add_child(), or
+ *      in the ui file with `<child type="ID">`.
  *
  * The following attributes are used when constructing sections:
- *
  * - "label": a user-visible string to use as section heading
  * - "display-hint": a string used to determine special formatting for the section.
- *     Possible values include "horizontal-buttons", "circular-buttons" and
- *     "inline-buttons". They all indicate that section should be
+ *     Possible values include "horizontal-buttons", "circular-buttons" and "inline-buttons". They all indicate that section should be
  *     displayed as a horizontal row of buttons.
- * - "text-direction": a string used to determine the `GtkTextDirection` to use
+ * - "text-direction": a string used to determine the #GtkTextDirection to use
  *     when "display-hint" is set to "horizontal-buttons". Possible values
  *     include "rtl", "ltr", and "none".
  *
  * The following attributes are used when constructing submenus:
- *
  * - "label": a user-visible string to display
  * - "icon": icon name to display
  *
  * Menu items will also show accelerators, which are usually associated
- * with actions via [method@Gtk.Application.set_accels_for_action],
- * [id@gtk_widget_class_add_binding_action] or
- * [method@Gtk.ShortcutController.add_shortcut].
+ * with actions via gtk_application_set_accels_for_action(),
+ * gtk_widget_class_add_binding_action() or gtk_shortcut_controller_add_shortcut().
  *
  * # CSS Nodes
  *
- * `GtkPopoverMenu` is just a subclass of `GtkPopover` that adds custom content
- * to it, therefore it has the same CSS nodes. It is one of the cases that add
- * a .menu style class to the popover's main node.
+ * #GtkPopoverMenu is just a subclass of #GtkPopover that adds
+ * custom content to it, therefore it has the same CSS nodes.
+ * It is one of the cases that add a .menu style class to
+ * the popover's main node.
  *
  * # Accessibility
  *
- * `GtkPopoverMenu` uses the %GTK_ACCESSIBLE_ROLE_MENU role, and its
- * items use the %GTK_ACCESSIBLE_ROLE_MENU_ITEM,
- * %GTK_ACCESSIBLE_ROLE_MENU_ITEM_CHECKBOX or
- * %GTK_ACCESSIBLE_ROLE_MENU_ITEM_RADIO roles, depending on the
+ * GtkPopoverMenu uses the #GTK_ACCESSIBLE_ROLE_MENU role, and its
+ * items use the #GTK_ACCESSIBLE_ROLE_MENU_ITEM, #GTK_ACCESSIBLE_ROLE_MENU_ITEM_CHECKBOX or #GTK_ACCESSIBLE_ROLE_MENU_ITEM_RADIO roles, depending on the
  * action they are connected to.
  */
 
@@ -301,23 +289,16 @@ leave_cb (GtkEventController *controller,
 static void
 gtk_popover_menu_init (GtkPopoverMenu *popover)
 {
-  GtkWidget *sw;
   GtkWidget *stack;
   GtkEventController *controller;
   GtkEventController **controllers;
   guint n_controllers, i;
 
-  sw = gtk_scrolled_window_new ();
-  gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
-  gtk_scrolled_window_set_propagate_natural_width (GTK_SCROLLED_WINDOW (sw), TRUE);
-  gtk_scrolled_window_set_propagate_natural_height (GTK_SCROLLED_WINDOW (sw), TRUE);
-  gtk_popover_set_child (GTK_POPOVER (popover), sw);
-
   stack = gtk_stack_new ();
   gtk_stack_set_vhomogeneous (GTK_STACK (stack), FALSE);
   gtk_stack_set_transition_type (GTK_STACK (stack), GTK_STACK_TRANSITION_TYPE_SLIDE_LEFT_RIGHT);
   gtk_stack_set_interpolate_size (GTK_STACK (stack), TRUE);
-  gtk_scrolled_window_set_child (GTK_SCROLLED_WINDOW (sw), stack);
+  gtk_popover_set_child (GTK_POPOVER (popover), stack);
   g_signal_connect (stack, "notify::visible-child-name",
                     G_CALLBACK (visible_submenu_changed), popover);
 
@@ -345,16 +326,6 @@ gtk_popover_menu_init (GtkPopoverMenu *popover)
   gtk_popover_set_cascade_popdown (GTK_POPOVER (popover), TRUE);
 }
 
-GtkWidget *
-gtk_popover_menu_get_stack (GtkPopoverMenu *menu)
-{
-  GtkWidget *sw = gtk_popover_get_child (GTK_POPOVER (menu));
-  GtkWidget *vp = gtk_scrolled_window_get_child (GTK_SCROLLED_WINDOW (sw));
-  GtkWidget *stack = gtk_viewport_get_child (GTK_VIEWPORT (vp));
-
-  return stack;
-}
-
 static void
 gtk_popover_menu_dispose (GObject *object)
 {
@@ -391,16 +362,16 @@ gtk_popover_menu_get_property (GObject    *object,
                                GValue     *value,
                                GParamSpec *pspec)
 {
-  GtkPopoverMenu *menu = GTK_POPOVER_MENU (object);
+  GtkWidget *stack = gtk_popover_get_child (GTK_POPOVER (object));
 
   switch (property_id)
     {
     case PROP_VISIBLE_SUBMENU:
-      g_value_set_string (value, gtk_stack_get_visible_child_name (GTK_STACK (gtk_popover_menu_get_stack (menu))));
+      g_value_set_string (value, gtk_stack_get_visible_child_name (GTK_STACK (stack)));
       break;
 
     case PROP_MENU_MODEL:
-      g_value_set_object (value, gtk_popover_menu_get_menu_model (menu));
+      g_value_set_object (value, gtk_popover_menu_get_menu_model (GTK_POPOVER_MENU (object)));
       break;
 
     default:
@@ -415,16 +386,16 @@ gtk_popover_menu_set_property (GObject      *object,
                                const GValue *value,
                                GParamSpec   *pspec)
 {
-  GtkPopoverMenu *menu = GTK_POPOVER_MENU (object);
+  GtkWidget *stack = gtk_popover_get_child (GTK_POPOVER (object));
 
   switch (property_id)
     {
     case PROP_VISIBLE_SUBMENU:
-      gtk_stack_set_visible_child_name (GTK_STACK (gtk_popover_menu_get_stack (menu)), g_value_get_string (value));
+      gtk_stack_set_visible_child_name (GTK_STACK (stack), g_value_get_string (value));
       break;
 
     case PROP_MENU_MODEL:
-      gtk_popover_menu_set_menu_model (menu, g_value_get_object (value));
+      gtk_popover_menu_set_menu_model (GTK_POPOVER_MENU (object), g_value_get_object (value));
       break;
 
     default:
@@ -578,11 +549,6 @@ gtk_popover_menu_class_init (GtkPopoverMenuClass *klass)
   widget_class->show = gtk_popover_menu_show;
   widget_class->move_focus = gtk_popover_menu_move_focus;
 
-  /**
-   * GtkPopoverMenu:visible-submenu:
-   *
-   * The name of the visible submenu.
-   */
   g_object_class_install_property (object_class,
                                    PROP_VISIBLE_SUBMENU,
                                    g_param_spec_string ("visible-submenu",
@@ -591,11 +557,6 @@ gtk_popover_menu_class_init (GtkPopoverMenuClass *klass)
                                                         NULL,
                                                         G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
-  /**
-   * GtkPopoverMenu:menu-model: (attributes org.gtk.Property.get=gtk_popover_menu_get_menu_model org.gtk.Property.set=gtk_popover_menu_set_menu_model)
-   *
-   * The model from which the menu is made.
-   */
   g_object_class_install_property (object_class,
                                    PROP_MENU_MODEL,
                                    g_param_spec_object ("menu-model",
@@ -658,7 +619,7 @@ gtk_popover_menu_buildable_iface_init (GtkBuildableIface *iface)
  *
  * Creates a new popover menu.
  *
- * Returns: a new `GtkPopoverMenu`
+ * Returns: a new #GtkPopoverMenu
  */
 GtkWidget *
 gtk_popover_menu_new (void)
@@ -674,16 +635,16 @@ gtk_popover_menu_new (void)
 
 /*<private>
  * gtk_popover_menu_open_submenu:
- * @popover: a `GtkPopoverMenu`
+ * @popover: a #GtkPopoverMenu
  * @name: the name of the menu to switch to
  *
  * Opens a submenu of the @popover. The @name
  * must be one of the names given to the submenus
- * of @popover with `GtkPopoverMenu:submenu`, or
+ * of @popover with #GtkPopoverMenu:submenu, or
  * "main" to switch back to the main menu.
  *
- * `GtkModelButton` will open submenus automatically
- * when the `GtkModelButton:menu-name` property is set,
+ * #GtkModelButton will open submenus automatically
+ * when the #GtkModelButton:menu-name property is set,
  * so this function is only needed when you are using
  * other kinds of widgets to initiate menu changes.
  */
@@ -695,7 +656,7 @@ gtk_popover_menu_open_submenu (GtkPopoverMenu *popover,
 
   g_return_if_fail (GTK_IS_POPOVER_MENU (popover));
 
-  stack = gtk_popover_menu_get_stack (popover);
+  stack = gtk_popover_get_child (GTK_POPOVER (popover));
   gtk_stack_set_visible_child_name (GTK_STACK (stack), name);
 }
 
@@ -704,29 +665,30 @@ gtk_popover_menu_add_submenu (GtkPopoverMenu *popover,
                               GtkWidget      *submenu,
                               const char     *name)
 {
-  GtkWidget *stack = gtk_popover_menu_get_stack (popover);
+  GtkWidget *stack = gtk_popover_get_child (GTK_POPOVER (popover));
   gtk_stack_add_named (GTK_STACK (stack), submenu, name);
 }
 
 /**
  * gtk_popover_menu_new_from_model:
- * @model: (nullable): a `GMenuModel`
+ * @model: (allow-none): a #GMenuModel, or %NULL
  *
- * Creates a `GtkPopoverMenu` and populates it according to @model.
+ * Creates a #GtkPopoverMenu and populates it according to
+ * @model.
  *
  * The created buttons are connected to actions found in the
- * `GtkApplicationWindow` to which the popover belongs - typically
+ * #GtkApplicationWindow to which the popover belongs - typically
  * by means of being attached to a widget that is contained within
- * the `GtkApplicationWindow`s widget hierarchy.
+ * the #GtkApplicationWindows widget hierarchy.
  *
- * Actions can also be added using [method@Gtk.Widget.insert_action_group]
+ * Actions can also be added using gtk_widget_insert_action_group()
  * on the menus attach widget or on any of its parent widgets.
  *
  * This function creates menus with sliding submenus.
- * See [ctor@Gtk.PopoverMenu.new_from_model_full] for a way
+ * See gtk_popover_menu_new_from_model_full() for a way
  * to control this.
  *
- * Returns: the new `GtkPopoverMenu`
+ * Returns: the new #GtkPopoverMenu
  */
 GtkWidget *
 gtk_popover_menu_new_from_model (GMenuModel *model)
@@ -737,22 +699,23 @@ gtk_popover_menu_new_from_model (GMenuModel *model)
 
 /**
  * gtk_popover_menu_new_from_model_full:
- * @model: a `GMenuModel`
+ * @model: a #GMenuModel
  * @flags: flags that affect how the menu is created
  *
- * Creates a `GtkPopoverMenu` and populates it according to @model.
+ * Creates a #GtkPopoverMenu and populates it according to
+ * @model.
  *
  * The created buttons are connected to actions found in the
  * action groups that are accessible from the parent widget.
- * This includes the `GtkApplicationWindow` to which the popover
- * belongs. Actions can also be added using [method@Gtk.Widget.insert_action_group]
+ * This includes the #GtkApplicationWindow to which the popover
+ * belongs. Actions can also be added using gtk_widget_insert_action_group()
  * on the parent widget or on any of its parent widgets.
  *
  * The only flag that is supported currently is
- * %GTK_POPOVER_MENU_NESTED, which makes GTK create traditional,
+ * #GTK_POPOVER_MENU_NESTED, which makes GTK create traditional,
  * nested submenus instead of the default sliding submenus.
  *
- * Returns: (transfer full): the new `GtkPopoverMenu`
+ * Returns: (transfer full): the new #GtkPopoverMenu
  */
 GtkWidget *
 gtk_popover_menu_new_from_model_full (GMenuModel          *model,
@@ -770,9 +733,9 @@ gtk_popover_menu_new_from_model_full (GMenuModel          *model,
 }
 
 /**
- * gtk_popover_menu_set_menu_model: (attributes org.gtk.Method.set_property=menu-model)
- * @popover: a `GtkPopoverMenu`
- * @model: (nullable): a `GMenuModel`
+ * gtk_popover_menu_set_menu_model:
+ * @popover: a #GtkPopoverMenu
+ * @model: (nullable): a #GMenuModel, or %NULL
  *
  * Sets a new menu model on @popover.
  *
@@ -792,7 +755,7 @@ gtk_popover_menu_set_menu_model (GtkPopoverMenu *popover,
       GtkWidget *stack;
       GtkWidget *child;
 
-      stack = gtk_popover_menu_get_stack (popover);
+      stack = gtk_popover_get_child (GTK_POPOVER (popover));
       while ((child = gtk_widget_get_first_child (stack)))
         gtk_stack_remove (GTK_STACK (stack), child);
 
@@ -804,8 +767,8 @@ gtk_popover_menu_set_menu_model (GtkPopoverMenu *popover,
 }
 
 /**
- * gtk_popover_menu_get_menu_model: (attributes org.gtk.Method.get_property=menu-model)
- * @popover: a `GtkPopoverMenu`
+ * gtk_popover_menu_get_menu_model:
+ * @popover: a #GtkPopoverMenu
  *
  * Returns the menu model used to populate the popover.
  *
@@ -821,14 +784,14 @@ gtk_popover_menu_get_menu_model (GtkPopoverMenu *popover)
 
 /**
  * gtk_popover_menu_add_child:
- * @popover: a `GtkPopoverMenu`
- * @child: the `GtkWidget` to add
+ * @popover: a #GtkPopoverMenu
+ * @child: the #GtkWidget to add
  * @id: the ID to insert @child at
  *
  * Adds a custom widget to a generated menu.
  *
- * For this to work, the menu model of @popover must have
- * an item with a `custom` attribute that matches @id.
+ * For this to work, the menu model of @popover must have an
+ * item with a `custom` attribute that matches @id.
  *
  * Returns: %TRUE if @id was found and the widget added
  */
@@ -847,8 +810,8 @@ gtk_popover_menu_add_child (GtkPopoverMenu *popover,
 
 /**
  * gtk_popover_menu_remove_child:
- * @popover: a `GtkPopoverMenu`
- * @child: the `GtkWidget` to remove
+ * @popover: a #GtkPopoverMenu
+ * @child: the #GtkWidget to remove
  *
  * Removes a widget that has previously been added with
  * gtk_popover_menu_add_child().
