@@ -30,6 +30,10 @@ struct _GtkRootInterface
 
 GtkConstraintSolver *   gtk_root_get_constraint_solver  (GtkRoot *self);
 
+void             gtk_root_start_layout  (GtkRoot *self);
+void             gtk_root_stop_layout   (GtkRoot *self);
+void             gtk_root_queue_restyle (GtkRoot *self);
+
 G_END_DECLS
 
 #endif /* __GTK_ROOT_PRIVATE_H__ */
