@@ -19,49 +19,51 @@
 
 
 /**
- * GtkShortcutController:
+ * SECTION:gtkshortcutcontroller
+ * @Short_description: Event controller for shortcuts
+ * @Title: GtkShortcutController
+ * @See_also: #GtkEventController, #GtkShortcut
  *
- * `GtkShortcutController` is an event controller that manages shortcuts.
+ * #GtkShortcutController is an event controller that manages shortcuts.
  *
  * Most common shortcuts are using this controller implicitly, e.g. by
- * adding a mnemonic underline to a `GtkLabel`, or by installing a key
- * binding using [method@Gtk.WidgetClass.add_binding], or by adding accelerators
- * to global actions using [method@Gtk.Application.set_accels_for_action].
+ * adding a mnemonic underline to a #GtkLabel, or by installing a key
+ * binding using gtk_widget_class_add_binding(), or by adding accelerators
+ * to global actions using gtk_application_set_accels_for_action().
  *
  * But it is possible to create your own shortcut controller, and add
  * shortcuts to it.
  *
- * `GtkShortcutController` implements `GListModel` for querying the
- * shortcuts that have been added to it.
+ * #GtkShortcutController implements #GListModel for querying the shortcuts that
+ * have been added to it.
  *
  * # GtkShortcutController as a GtkBuildable
  *
- * `GtkShortcutControllers` can be creates in ui files to set up
- * shortcuts in the same place as the widgets.
+ * GtkShortcutControllers can be creates in ui files to set up shortcuts
+ * in the same place as the widgets.
  *
- * An example of a UI definition fragment with `GtkShortcutController`:
- * ```xml
+ * An example of a UI definition fragment with GtkShortcutController:
+ * |[
  *   <object class='GtkButton'>
  *     <child>
  *       <object class='GtkShortcutController'>
  *         <property name='scope'>managed</property>
  *         <child>
  *           <object class='GtkShortcut'>
- *             <property name='trigger'>&lt;Control&gt;k</property>
+ *             <property name='trigger'>&amp;lt;Control&amp;gt;k</property>
  *             <property name='action'>activate</property>
  *           </object>
  *         </child>
  *       </object>
  *     </child>
  *   </object>
- * ```
+ * ]|
  *
- * This example creates a [class@Gtk.ActivateAction] for triggering the
- * `activate` signal of the `GtkButton`. See [ctor@Gtk.ShortcutAction.parse_string]
- * for the syntax for other kinds of `GtkShortcutAction`. See
- * [ctor@Gtk.ShortcutTrigger.parse_string] to learn more about the syntax
- * for triggers.
- */
+ * This example creates a #GtkActivateAction for triggering the `activate`
+ * signal of the GtkButton. See gtk_shortcut_action_parse_string() for the syntax
+ * for other kinds of #GtkShortcutAction. See gtk_shortcut_trigger_parse_string()
+ * to learn more about the syntax for triggers.
+ **/
 
 #include "config.h"
 
@@ -78,7 +80,6 @@
 #include "gtkwidgetprivate.h"
 #include "gtknative.h"
 #include "gtkdebug.h"
-#include "gtkmodelbuttonprivate.h"
 
 #include <gdk/gdk.h>
 
@@ -433,11 +434,9 @@ gtk_shortcut_controller_handle_event (GtkEventController *controller,
 
   if (event_type == GDK_KEY_PRESS)
     {
-      GdkModifierType modifiers, consumed_modifiers;
-
+      GdkModifierType modifiers;
       modifiers = gdk_event_get_modifier_state (event);
-      consumed_modifiers = gdk_key_event_get_consumed_modifiers (event);
-      enable_mnemonics = (modifiers & ~consumed_modifiers & gtk_accelerator_get_default_mod_mask ()) == self->mnemonics_modifiers;
+      enable_mnemonics = (modifiers & gtk_accelerator_get_default_mod_mask ()) == self->mnemonics_modifiers;
     }
   else
     {
@@ -481,17 +480,16 @@ update_accel (GtkShortcut    *shortcut,
   g_free (accel);
 }
 
-void
-gtk_shortcut_controller_update_accels (GtkShortcutController *self)
+static void
+gtk_shortcut_controller_set_widget (GtkEventController *controller,
+                                    GtkWidget          *widget)
 {
+  GtkShortcutController *self = GTK_SHORTCUT_CONTROLLER (controller);
   GListModel *shortcuts = self->shortcuts;
-  GtkWidget *widget;
   GtkActionMuxer *muxer;
   guint i, p;
 
-  widget = gtk_event_controller_get_widget (GTK_EVENT_CONTROLLER (self));
-  if (!widget || GTK_IS_MODEL_BUTTON (widget))
-    return;
+  GTK_EVENT_CONTROLLER_CLASS (gtk_shortcut_controller_parent_class)->set_widget (controller, widget);
 
   muxer = _gtk_widget_get_action_muxer (widget, TRUE);
   for (i = 0, p = g_list_model_get_n_items (shortcuts); i < p; i++)
@@ -501,17 +499,6 @@ gtk_shortcut_controller_update_accels (GtkShortcutController *self)
         update_accel (shortcut, muxer, TRUE);
       g_object_unref (shortcut);
     }
-}
-
-static void
-gtk_shortcut_controller_set_widget (GtkEventController *controller,
-                                    GtkWidget          *widget)
-{
-  GtkShortcutController *self = GTK_SHORTCUT_CONTROLLER (controller);
-
-  GTK_EVENT_CONTROLLER_CLASS (gtk_shortcut_controller_parent_class)->set_widget (controller, widget);
-
-  gtk_shortcut_controller_update_accels (self);
 
   if (_gtk_widget_get_root (widget))
     gtk_shortcut_controller_root (self);
@@ -556,7 +543,7 @@ gtk_shortcut_controller_class_init (GtkShortcutControllerClass *klass)
   controller_class->unset_widget = gtk_shortcut_controller_unset_widget;
 
   /**
-   * GtkShortcutController:mnemonic-modifiers: (attributes org.gtk.Property.get=gtk_shortcut_controller_get_mnemonics_modifiers org.gtk.Property.set=gtk_shortcut_controller_set_mnemonics_modifiers)
+   * GtkShortcutController:mnemonic-modifiers:
    *
    * The modifiers that need to be pressed to allow mnemonics activation.
    */
@@ -571,7 +558,7 @@ gtk_shortcut_controller_class_init (GtkShortcutControllerClass *klass)
   /**
    * GtkShortcutController:model:
    *
-   * A list model to take shortcuts from.
+   * A list model to take shortcuts from
    */
   properties[PROP_MODEL] =
       g_param_spec_object ("model",
@@ -581,7 +568,7 @@ gtk_shortcut_controller_class_init (GtkShortcutControllerClass *klass)
                            G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_EXPLICIT_NOTIFY | G_PARAM_STATIC_STRINGS);
 
   /**
-   * GtkShortcutController:scope: (attributes org.gtk.Property.get=gtk_shortcut_controller_get_scope org.gtk.Property.set=gtk_shortcut_controller_set_scope)
+   * GtkShortcutController:scope:
    *
    * What scope the shortcuts will be handled in.
    */
@@ -708,7 +695,7 @@ gtk_shortcut_controller_new (void)
 
 /**
  * gtk_shortcut_controller_new_for_model:
- * @model: a `GListModel` containing shortcuts
+ * @model: a #GListModel containing shortcuts
  *
  * Creates a new shortcut controller that takes its shortcuts from
  * the given list model.
@@ -732,13 +719,13 @@ gtk_shortcut_controller_new_for_model (GListModel *model)
 /**
  * gtk_shortcut_controller_add_shortcut:
  * @self: the controller
- * @shortcut: (transfer full): a `GtkShortcut`
+ * @shortcut: (transfer full): a #GtkShortcut
  *
  * Adds @shortcut to the list of shortcuts handled by @self.
  *
  * If this controller uses an external shortcut list, this
  * function does nothing.
- */
+ **/
 void
 gtk_shortcut_controller_add_shortcut (GtkShortcutController *self,
                                       GtkShortcut           *shortcut)
@@ -769,7 +756,7 @@ gtk_shortcut_controller_add_shortcut (GtkShortcutController *self,
 /**
  * gtk_shortcut_controller_remove_shortcut:
  * @self: the controller
- * @shortcut: a `GtkShortcut`
+ * @shortcut: a #GtkShortcut
  *
  * Removes @shortcut from the list of shortcuts handled by @self.
  *
@@ -813,8 +800,8 @@ gtk_shortcut_controller_remove_shortcut (GtkShortcutController  *self,
 }
 
 /**
- * gtk_shortcut_controller_set_scope: (attributes org.gtk.Method.set_property=scope)
- * @self: a `GtkShortcutController`
+ * gtk_shortcut_controller_set_scope:
+ * @self: a #GtkShortcutController
  * @scope: the new scope to use
  *
  * Sets the controller to have the given @scope.
@@ -826,7 +813,7 @@ gtk_shortcut_controller_remove_shortcut (GtkShortcutController  *self,
  *
  * With %GTK_SHORTCUT_SCOPE_LOCAL, shortcuts will only be activated
  * when the widget has focus.
- */
+ **/
 void
 gtk_shortcut_controller_set_scope (GtkShortcutController *self,
                                    GtkShortcutScope       scope)
@@ -852,15 +839,14 @@ gtk_shortcut_controller_set_scope (GtkShortcutController *self,
 }
 
 /**
- * gtk_shortcut_controller_get_scope: (attributes org.gtk.Method.get_property=scope)
- * @self: a `GtkShortcutController`
+ * gtk_shortcut_controller_get_scope:
+ * @self: a #GtkShortcutController
  *
- * Gets the scope for when this controller activates its shortcuts.
- *
- * See [method@Gtk.ShortcutController.set_scope] for details.
+ * Gets the scope for when this controller activates its shortcuts. See
+ * gtk_shortcut_controller_set_scope() for details.
  *
  * Returns: the controller's scope
- */
+ **/
 GtkShortcutScope
 gtk_shortcut_controller_get_scope (GtkShortcutController *self)
 {
@@ -870,16 +856,16 @@ gtk_shortcut_controller_get_scope (GtkShortcutController *self)
 }
 
 /**
- * gtk_shortcut_controller_set_mnemonics_modifiers: (attributes org.gtk.MEthod.set_property=mnemonic-modifiers)
- * @self: a `GtkShortcutController`
+ * gtk_shortcut_controller_set_mnemonics_modifiers:
+ * @self: a #GtkShortcutController
  * @modifiers: the new mnemonics_modifiers to use
  *
- * Sets the controller to use the given modifier for mnemonics.
+ * Sets the controller to have the given @mnemonics_modifiers.
  *
  * The mnemonics modifiers determines which modifiers need to be pressed to allow
  * activation of shortcuts with mnemonics triggers.
  *
- * GTK normally uses the Alt modifier for mnemonics, except in `GtkPopoverMenu`s,
+ * GTK normally uses the Alt modifier for mnemonics, except in #GtkPopoverMenus,
  * where mnemonics can be triggered without any modifiers. It should be very
  * rarely necessary to change this, and doing so is likely to interfere with
  * other shortcuts.
@@ -887,7 +873,7 @@ gtk_shortcut_controller_get_scope (GtkShortcutController *self)
  * This value is only relevant for local shortcut controllers. Global and managed
  * shortcut controllers will have their shortcuts activated from other places which
  * have their own modifiers for activating mnemonics.
- */
+ **/
 void
 gtk_shortcut_controller_set_mnemonics_modifiers (GtkShortcutController *self,
                                                  GdkModifierType        modifiers)
@@ -903,13 +889,14 @@ gtk_shortcut_controller_set_mnemonics_modifiers (GtkShortcutController *self,
 }
 
 /**
- * gtk_shortcut_controller_get_mnemonics_modifiers: (attributes org.gtk.Method.get_property=mnemonic-modifiers)
- * @self: a `GtkShortcutController`
+ * gtk_shortcut_controller_get_mnemonics_modifiers:
+ * @self: a #GtkShortcutController
  *
- * Gets the mnemonics modifiers for when this controller activates its shortcuts.
+ * Gets the mnemonics modifiers for when this controller activates its shortcuts. See
+ * gtk_shortcut_controller_set_mnemonics_modifiers() for details.
  *
  * Returns: the controller's mnemonics modifiers
- */
+ **/
 GdkModifierType
 gtk_shortcut_controller_get_mnemonics_modifiers (GtkShortcutController *self)
 {
@@ -917,3 +904,4 @@ gtk_shortcut_controller_get_mnemonics_modifiers (GtkShortcutController *self)
 
   return self->mnemonics_modifiers;
 }
+
