@@ -26,7 +26,6 @@
 #include "gtkimage.h"
 #include "gtkintl.h"
 #include "gtklabel.h"
-#include "gtkorientable.h"
 #include "gtkprivate.h"
 #include "gtkselectionmodel.h"
 #include "gtktogglebutton.h"
@@ -34,41 +33,36 @@
 #include "gtkwidgetprivate.h"
 
 /**
- * GtkStackSwitcher:
+ * SECTION:gtkstackswitcher
+ * @Short_description: A controller for GtkStack
+ * @Title: GtkStackSwitcher
+ * @See_also: #GtkStack
  *
- * The `GtkStackSwitcher` shows a row of buttons to switch between `GtkStack`
- * pages.
+ * The GtkStackSwitcher widget acts as a controller for a
+ * #GtkStack; it shows a row of buttons to switch between
+ * the various pages of the associated stack widget.
  *
- * ![An example GtkStackSwitcher](stackswitcher.png)
+ * All the content for the buttons comes from the child properties
+ * of the #GtkStack; the button visibility in a #GtkStackSwitcher
+ * widget is controlled by the visibility of the child in the
+ * #GtkStack.
  *
- * It acts as a controller for the associated `GtkStack`.
- *
- * All the content for the buttons comes from the properties of the stacks
- * [class@Gtk.StackPage] objects; the button visibility in a `GtkStackSwitcher`
- * widget is controlled by the visibility of the child in the `GtkStack`.
- *
- * It is possible to associate multiple `GtkStackSwitcher` widgets
- * with the same `GtkStack` widget.
+ * It is possible to associate multiple #GtkStackSwitcher widgets
+ * with the same #GtkStack widget.
  *
  * # CSS nodes
  *
- * `GtkStackSwitcher` has a single CSS node named stackswitcher and
+ * GtkStackSwitcher has a single CSS node named stackswitcher and
  * style class .stack-switcher.
  *
- * When circumstances require it, `GtkStackSwitcher` adds the
+ * When circumstances require it, GtkStackSwitcher adds the
  * .needs-attention style class to the widgets representing the
  * stack pages.
  *
  * # Accessibility
  *
- * `GtkStackSwitcher` uses the %GTK_ACCESSIBLE_ROLE_TAB_LIST role
- * and uses the %GTK_ACCESSIBLE_ROLE_TAB for its buttons.
- *
- * # Orientable
- *
- * Since GTK 4.4, `GtkStackSwitcher` implements `GtkOrientable` allowing
- * the stack switcher to be made vertical with
- * `gtk_orientable_set_orientation()`.
+ * GtkStackSwitcher uses the #GTK_ACCESSIBLE_ROLE_TAB_LIST role
+ * and uses the #GTK_ACCESSIBLE_ROLE_TAB for its buttons.
  */
 
 #define TIMEOUT_EXPAND 500
@@ -91,12 +85,10 @@ struct _GtkStackSwitcherClass
 
 enum {
   PROP_0,
-  PROP_STACK,
-  PROP_ORIENTATION
+  PROP_STACK
 };
 
-G_DEFINE_TYPE_WITH_CODE (GtkStackSwitcher, gtk_stack_switcher, GTK_TYPE_WIDGET,
-                         G_IMPLEMENT_INTERFACE (GTK_TYPE_ORIENTABLE, NULL))
+G_DEFINE_TYPE (GtkStackSwitcher, gtk_stack_switcher, GTK_TYPE_WIDGET)
 
 static void
 gtk_stack_switcher_init (GtkStackSwitcher *switcher)
@@ -163,10 +155,6 @@ rebuild_child (GtkWidget   *self,
       gtk_widget_set_halign (GTK_WIDGET (button_child), GTK_ALIGN_CENTER);
       gtk_button_set_child (GTK_BUTTON (self), button_child);
     }
-
-  gtk_accessible_update_property (GTK_ACCESSIBLE (self),
-                                  GTK_ACCESSIBLE_PROPERTY_LABEL, title,
-                                  -1);
 }
 
 static void
@@ -225,14 +213,7 @@ gtk_stack_switcher_switch_timeout (gpointer data)
   return G_SOURCE_REMOVE;
 }
 
-static void
-clear_timer (gpointer data)
-{
-  if (data)
-    g_source_remove (GPOINTER_TO_UINT (data));
-}
-
-static void
+static void 
 gtk_stack_switcher_drag_enter (GtkDropControllerMotion *motion,
                                double                   x,
                                double                   y,
@@ -245,8 +226,8 @@ gtk_stack_switcher_drag_enter (GtkDropControllerMotion *motion,
       guint switch_timer = g_timeout_add (TIMEOUT_EXPAND,
                                           gtk_stack_switcher_switch_timeout,
                                           button);
-      gdk_source_set_static_name_by_id (switch_timer, "[gtk] gtk_stack_switcher_switch_timeout");
-      g_object_set_data_full (G_OBJECT (button), "-gtk-switch-timer", GUINT_TO_POINTER (switch_timer), clear_timer);
+      g_source_set_name_by_id (switch_timer, "[gtk] gtk_stack_switcher_switch_timeout");
+      g_object_set_data (G_OBJECT (button), "-gtk-switch-timer", GUINT_TO_POINTER (switch_timer));
     }
 }
 
@@ -411,9 +392,9 @@ unset_stack (GtkStackSwitcher *switcher)
 }
 
 /**
- * gtk_stack_switcher_set_stack: (attributes org.gtk.Method.set_property=stack)
- * @switcher: a `GtkStackSwitcher`
- * @stack: (nullable): a `GtkStack`
+ * gtk_stack_switcher_set_stack:
+ * @switcher: a #GtkStackSwitcher
+ * @stack: (allow-none): a #GtkStack
  *
  * Sets the stack to control.
  */
@@ -436,12 +417,14 @@ gtk_stack_switcher_set_stack (GtkStackSwitcher *switcher,
 }
 
 /**
- * gtk_stack_switcher_get_stack: (attributes org.gtk.Method.get_property=stack)
- * @switcher: a `GtkStackSwitcher`
+ * gtk_stack_switcher_get_stack:
+ * @switcher: a #GtkStackSwitcher
  *
  * Retrieves the stack.
+ * See gtk_stack_switcher_set_stack().
  *
- * Returns: (nullable) (transfer none): the stack
+ * Returns: (nullable) (transfer none): the stack, or %NULL if
+ *    none has been set explicitly.
  */
 GtkStack *
 gtk_stack_switcher_get_stack (GtkStackSwitcher *switcher)
@@ -458,14 +441,9 @@ gtk_stack_switcher_get_property (GObject      *object,
                                  GParamSpec   *pspec)
 {
   GtkStackSwitcher *switcher = GTK_STACK_SWITCHER (object);
-  GtkLayoutManager *box_layout = gtk_widget_get_layout_manager (GTK_WIDGET (switcher));
 
   switch (prop_id)
     {
-    case PROP_ORIENTATION:
-      g_value_set_enum (value, gtk_orientable_get_orientation (GTK_ORIENTABLE (box_layout)));
-      break;
-
     case PROP_STACK:
       g_value_set_object (value, switcher->stack);
       break;
@@ -483,22 +461,9 @@ gtk_stack_switcher_set_property (GObject      *object,
                                  GParamSpec   *pspec)
 {
   GtkStackSwitcher *switcher = GTK_STACK_SWITCHER (object);
-  GtkLayoutManager *box_layout = gtk_widget_get_layout_manager (GTK_WIDGET (switcher));
 
   switch (prop_id)
     {
-    case PROP_ORIENTATION:
-      {
-        GtkOrientation orientation = g_value_get_enum (value);
-        if (gtk_orientable_get_orientation (GTK_ORIENTABLE (box_layout)) != orientation)
-          {
-            gtk_orientable_set_orientation (GTK_ORIENTABLE (box_layout), orientation);
-            gtk_widget_update_orientation (GTK_WIDGET (switcher), orientation);
-            g_object_notify_by_pspec (object, pspec);
-          }
-      }
-      break;
-
     case PROP_STACK:
       gtk_stack_switcher_set_stack (switcher, g_value_get_object (value));
       break;
@@ -540,11 +505,6 @@ gtk_stack_switcher_class_init (GtkStackSwitcherClass *class)
   object_class->dispose = gtk_stack_switcher_dispose;
   object_class->finalize = gtk_stack_switcher_finalize;
 
-  /**
-   * GtkStackSwitcher:stack: (attributes org.gtk.Property.get=gtk_stack_switcher_get_stack org.gtk.Property.set=gtk_stack_switcher_set_stack)
-   *
-   * The stack.
-   */
   g_object_class_install_property (object_class,
                                    PROP_STACK,
                                    g_param_spec_object ("stack",
@@ -554,8 +514,6 @@ gtk_stack_switcher_class_init (GtkStackSwitcherClass *class)
                                                         GTK_PARAM_READWRITE |
                                                         G_PARAM_CONSTRUCT));
 
-  g_object_class_override_property (object_class, PROP_ORIENTATION, "orientation");
-
   gtk_widget_class_set_layout_manager_type (widget_class, GTK_TYPE_BOX_LAYOUT);
   gtk_widget_class_set_css_name (widget_class, I_("stackswitcher"));
   gtk_widget_class_set_accessible_role (widget_class, GTK_ACCESSIBLE_ROLE_TAB_LIST);
@@ -564,9 +522,9 @@ gtk_stack_switcher_class_init (GtkStackSwitcherClass *class)
 /**
  * gtk_stack_switcher_new:
  *
- * Create a new `GtkStackSwitcher`.
+ * Create a new #GtkStackSwitcher.
  *
- * Returns: a new `GtkStackSwitcher`.
+ * Returns: a new #GtkStackSwitcher.
  */
 GtkWidget *
 gtk_stack_switcher_new (void)
