@@ -26,7 +26,8 @@
 #include "gtkwidgetprivate.h"
 #include "gtkrendericonprivate.h"
 #include "gtkcssboxesimplprivate.h"
-#include "gtkcssnodeprivate.h"
+#include "gtkcssnumbervalueprivate.h"
+#include "gtkstylecontextprivate.h"
 #include "gtknativeprivate.h"
 #include "gtkintl.h"
 
@@ -109,15 +110,17 @@ gtk_text_handle_native_get_surface_transform (GtkNative *native,
 
 static void
 gtk_text_handle_get_padding (GtkTextHandle *handle,
-                             GtkBorder     *padding)
+                             GtkBorder     *border)
 {
   GtkWidget *widget = GTK_WIDGET (handle);
-  GtkCssStyle *style = gtk_css_node_get_style (gtk_widget_get_css_node (widget));
+  GtkStyleContext *context;
 
-  padding->left = _gtk_css_number_value_get (style->size->padding_left, 100);
-  padding->right = _gtk_css_number_value_get (style->size->padding_right, 100);
-  padding->top = _gtk_css_number_value_get (style->size->padding_top, 100);
-  padding->bottom = _gtk_css_number_value_get (style->size->padding_bottom, 100);
+  context = gtk_widget_get_style_context (widget);
+
+  border->left = _gtk_css_number_value_get (_gtk_style_context_peek_property (context, GTK_CSS_PROPERTY_PADDING_LEFT), 100);
+  border->right = _gtk_css_number_value_get (_gtk_style_context_peek_property (context, GTK_CSS_PROPERTY_PADDING_RIGHT), 100);
+  border->top = _gtk_css_number_value_get (_gtk_style_context_peek_property (context, GTK_CSS_PROPERTY_PADDING_TOP), 100);
+  border->bottom = _gtk_css_number_value_get (_gtk_style_context_peek_property (context, GTK_CSS_PROPERTY_PADDING_BOTTOM), 100);
 }
 
 static void
